@@ -142,31 +142,41 @@ class ApiList(View):
             if isinstance(ar.bound_action.action, ShowEmptyTable):
                 elem = ar.create_instance()
                 datarec = elem2rec_empty(ar, ar.ah, elem)
-                datarec.update(test_version_mismatch(request))
+                vm = test_version_mismatch(request)
+                if vm:
+                    datarec.update(vm)
+                    resp = json_response(datarec)
+                    resp['Clear-Site-Data'] = '"cache", "storage", "executionContexts"'
+                    return resp
                 return json_response(datarec)
 
             display_mode = request.GET.get(
                 constants.URL_PARAM_DISPLAY_MODE, constants.DISPLAY_MODE_TABLE)
 
-            def serialize(ar, row):
-                """Use display_mode to determine which serilisation store method and fields to use"""
-                if display_mode == constants.DISPLAY_MODE_TABLE:
-                    return rh.store.row2list(ar, row)
-                elif display_mode == constants.DISPLAY_MODE_GALLERY:
-                    # return rh.store.file2url(ar, row)
-                    return row.get_gallery_item(ar)
-                else:
-                    if display_mode == constants.DISPLAY_MODE_CARDS:
-                        fields = rh.store.card_fields
-                    elif display_mode == constants.DISPLAY_MODE_LIST:
-                        fields = rh.store.item_fields
+            if display_mode == constants.DISPLAY_MODE_STORY:
+                story = ar.actor.as_story(None, ar)
+                rows = [{'id': obj.pk} for obj in ar.sliced_data_iterator]
+            else:
+                story = None
+                def serialize(ar, row):
+                    """Use display_mode to determine which serilisation store method and fields to use"""
+                    if display_mode == constants.DISPLAY_MODE_TABLE:
+                        return rh.store.row2list(ar, row)
+                    elif display_mode == constants.DISPLAY_MODE_GALLERY:
+                        # return rh.store.file2url(ar, row)
+                        return row.get_gallery_item(ar)
                     else:
-                        fields = rh.store.detail_fields
-                    return rh.store.row2dict(ar,
-                        row, fields=fields, card_title=ar.get_card_title(row))
+                        if display_mode == constants.DISPLAY_MODE_CARDS:
+                            fields = rh.store.card_fields
+                        elif display_mode == constants.DISPLAY_MODE_LIST:
+                            fields = rh.store.item_fields
+                        else:
+                            fields = rh.store.detail_fields
+                        return rh.store.row2dict(ar,
+                            row, fields=fields, card_title=ar.get_card_title(row))
 
-            rows = [serialize(ar, row)
-                    for row in ar.sliced_data_iterator]
+                rows = [serialize(ar, row)
+                        for row in ar.sliced_data_iterator]
 
             total_count = ar.get_total_count()
             if display_mode == constants.DISPLAY_MODE_TABLE:
@@ -178,6 +188,7 @@ class ApiList(View):
             # assert len(rows) <= ar.limit
             kw = dict(count=total_count,
                       rows=rows,
+                      story=story,
                       success=True,
                       no_data_text=ar.no_data_text,
                       title=ar.get_title())
@@ -189,7 +200,12 @@ class ApiList(View):
                 kw.update(
                     param_values=ar.actor.params_layout.params_store.pv2dict(
                         ar, ar.param_values))
-            kw.update(test_version_mismatch(request))
+            vm = test_version_mismatch(request)
+            if vm:
+                kw.update(vm)
+                resp = json_response(kw)
+                resp['Clear-Site-Data'] = '"cache", "storage", "executionContexts"'
+                return resp
             return json_response(kw)
 
         return settings.SITE.kernel.run_action(ar)
